pub enum SchemaError {
Show 20 variants
IoError {
path: String,
source: Error,
},
SyntaxError {
src: String,
span: SourceSpan,
message: String,
},
InvalidModel {
name: String,
message: String,
},
InvalidField {
model: String,
field: String,
message: String,
},
InvalidRelation {
model: String,
field: String,
message: String,
},
Duplicate {
kind: String,
name: String,
},
UnknownType {
model: String,
field: String,
type_name: String,
},
InvalidAttribute {
attribute: String,
message: String,
},
MissingId {
model: String,
},
ConfigError {
message: String,
},
TomlError {
source: Error,
},
ValidationFailed {
count: usize,
errors: Vec<SchemaError>,
},
MissingVectorDimension {
field: String,
},
InvalidVectorType {
value: String,
},
InvalidVectorMetric {
value: String,
},
InvalidVectorIndex {
value: String,
},
ParseInFile {
source: SourceId,
inner: Box<SchemaError>,
},
DuplicateAcrossFiles {
kind: DuplicateKind,
name: String,
first: SourceLoc,
second: SourceLoc,
},
MultipleDatasource {
first: SourceLoc,
second: SourceLoc,
},
EmptySchemaDirectory {
path: PathBuf,
},
}Expand description
Errors that can occur during schema parsing and validation.
Variants
IoError
Error reading a file.
SyntaxError
Syntax error in the schema file.
InvalidModel
Invalid model definition.
InvalidField
Invalid field definition.
InvalidRelation
Invalid relation definition.
Duplicate
Duplicate definition.
UnknownType
Unknown type reference.
InvalidAttribute
Invalid attribute.
MissingId
Missing required attribute.
ConfigError
Configuration error.
TomlError
TOML parsing error.
ValidationFailed
Validation error with multiple issues.
MissingVectorDimension
A Vector field is missing a required @dim(N) attribute.
InvalidVectorType
A Vector field has an invalid @vectorType value.
InvalidVectorMetric
A Vector field has an invalid @metric value.
InvalidVectorIndex
A Vector field has an invalid @index value.
ParseInFile
Parse failure in a specific file within a multi-file schema directory.
DuplicateAcrossFiles
Same-named item declared in two source files.
MultipleDatasource
More than one datasource block across source files.
EmptySchemaDirectory
Schema directory contained no *.prax files.
Implementations
Sourceimpl SchemaError
impl SchemaError
Sourcepub fn syntax(
src: impl Into<String>,
offset: usize,
len: usize,
message: impl Into<String>,
) -> SchemaError
pub fn syntax( src: impl Into<String>, offset: usize, len: usize, message: impl Into<String>, ) -> SchemaError
Create a syntax error with source location.
Sourcepub fn invalid_model(
name: impl Into<String>,
message: impl Into<String>,
) -> SchemaError
pub fn invalid_model( name: impl Into<String>, message: impl Into<String>, ) -> SchemaError
Create an invalid model error.
Sourcepub fn invalid_field(
model: impl Into<String>,
field: impl Into<String>,
message: impl Into<String>,
) -> SchemaError
pub fn invalid_field( model: impl Into<String>, field: impl Into<String>, message: impl Into<String>, ) -> SchemaError
Create an invalid field error.
Sourcepub fn invalid_relation(
model: impl Into<String>,
field: impl Into<String>,
message: impl Into<String>,
) -> SchemaError
pub fn invalid_relation( model: impl Into<String>, field: impl Into<String>, message: impl Into<String>, ) -> SchemaError
Create an invalid relation error.
Sourcepub fn duplicate(
kind: impl Into<String>,
name: impl Into<String>,
) -> SchemaError
pub fn duplicate( kind: impl Into<String>, name: impl Into<String>, ) -> SchemaError
Create a duplicate definition error.
Sourcepub fn unknown_type(
model: impl Into<String>,
field: impl Into<String>,
type_name: impl Into<String>,
) -> SchemaError
pub fn unknown_type( model: impl Into<String>, field: impl Into<String>, type_name: impl Into<String>, ) -> SchemaError
Create an unknown type error.