pub enum ScalarType {
}Expand description
Scalar types supported by Prax.
Variants
Int
Integer type (maps to INT/INTEGER).
BigInt
Big integer type (maps to BIGINT).
Float
Floating point type (maps to FLOAT/REAL).
Decimal
Decimal type for precise calculations (maps to DECIMAL/NUMERIC).
String
String type (maps to VARCHAR/TEXT).
Boolean
Boolean type.
DateTime
Date and time type.
Date
Date only type.
Time
Time only type.
Json
JSON type.
Bytes
Binary/Bytes type.
Uuid
UUID type (128-bit universally unique identifier).
Cuid
CUID type (collision-resistant unique identifier).
Cuid2
CUID2 type (next generation collision-resistant unique identifier).
NanoId
NanoID type (URL-friendly unique identifier).
Ulid
ULID type (Universally Unique Lexicographically Sortable Identifier).
Vector(Option<u32>)
Vector type for AI/ML embeddings (requires vector extension).
Stores dense vectors of float4 values.
Usage: embedding Vector(1536) for OpenAI embeddings.
HalfVector(Option<u32>)
Half-precision vector type (requires vector extension).
Stores dense vectors of float2 values, using half the storage of Vector.
Usage: embedding HalfVector(1536) for memory-efficient embeddings.
SparseVector(Option<u32>)
Sparse vector type (requires vector extension).
Stores sparse vectors with explicit indices and values.
Usage: features SparseVector(10000) for high-dimensional sparse data.
Bit(Option<u32>)
Bit vector type (requires vector extension).
Stores binary vectors for binary quantization.
Usage: hash Bit(256) for binary hash storage.
Implementations
Sourceimpl ScalarType
impl ScalarType
Sourcepub fn from_str(s: &str) -> Option<ScalarType>
pub fn from_str(s: &str) -> Option<ScalarType>
Parse a scalar type from a string.
For parameterized types like Vector(1536), use parse_with_param.
Sourcepub fn parse_with_param(name: &str, param: Option<u32>) -> Option<ScalarType>
pub fn parse_with_param(name: &str, param: Option<u32>) -> Option<ScalarType>
Parse a scalar type with an optional dimension parameter.
Handles types like Vector(1536), HalfVector(768), etc.
Sourcepub fn is_id_type(&self) -> bool
pub fn is_id_type(&self) -> bool
Check if this type is an identifier type (UUID, CUID, etc.).
Sourcepub fn requires_vector_extension(&self) -> bool
pub fn requires_vector_extension(&self) -> bool
Check if this type requires the vector PostgreSQL extension.
Sourcepub fn postgres_type(&self) -> String
pub fn postgres_type(&self) -> String
Get the PostgreSQL type name for this scalar type.